# -*- coding: utf-8 -*-
# pylint: disable=expression-not-assigned,line-too-long
"""API of interface operations for calculating binary year to date metrics with monthly cumulative slices.."""
# import os
import sys
from typing import List, Union


def main(argv: Union[List[str], None] = None) -> int:
    argv = sys.argv[1:] if argv is None else argv
    return 0
